Contar artigos por valores de campo e intervalos
Contar artigos por valores de campo e por intervalos na mesma análise
Parâmetros de entrada
| Parâmetro | Descrição | Tipo | Padrão | Obrigatório |
|---|---|---|---|---|
| title | Consulta de pesquisa. | string | Sim | |
| facet | Contar artigos por valor de campo. | boolean | true | Sim |
| facet.field | Campos para contagens por valor. | string | Sim | |
| facet.range | Contar artigos por intervalo. | boolean | true | Sim |
| facet.range.field | Campo para contagens por intervalo. | string | Sim | |
| facet.range.start | Valor inicial para o intervalo. | string | Sim | |
| facet.range.end | Valor de término para intervalo. | string | Sim | |
| facet.range.gap | Lacuna entre intervalos (e.g., 1MONTH). | string | Sim | |
| api_key | Sua chave API | string | Sim | |
| per_page | Número máximo de artigos a serem recuperados | integer | 20 | Não |
Exemplos de fluxo de trabalho
Contar artigos por valores de campo e intervalos:
curl -X GET "https://api.apitube.io/v1/news/everything?title=climate&facet=true&facet.field=source.country.id,language.id&facet.range=true&facet.range.field=published_at&facet.range.start=2024-01-01&facet.range.end=2024-06-01&facet.range.gap=1MONTH&api_key=YOUR_API_KEY"
Mostrar tom de cobertura ao longo do tempo:
curl -X GET "https://api.apitube.io/v1/news/everything?brand.name=Coca-Cola&facet.range=true&facet.range.field=published_at&facet.range.start=2024-01-01&facet.range.end=2024-12-31&facet.range.gap=1MONTH&sentiment.overall.polarity=positive&api_key=YOUR_API_KEY"
Rastreie quantas imagens e vídeos aparecem em artigos ao longo do tempo:
curl -X GET "https://api.apitube.io/v1/news/everything?has_image=1&facet.range=true&facet.range.field=media.images.count&facet.range.start=1&facet.range.end=20&facet.range.gap=2&api_key=YOUR_API_KEY"
Exemplos relacionados
- Contar resultados agrupados com múltiplos filtros
- Obtenha contagens de artigos por campo para análise
- Contar artigos por intervalo
- Selecionar campos específicos
- Obter artigos com imagens de alta qualidade
Receita para cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?title=climate&facet=1&facet.field=source.country.id%2Clanguage.id&facet.range=1&facet.range.field=published_at&facet.range.start=2024-01-01&facet.range.end=2024-06-01&facet.range.gap=1MONTH&api_key=YOUR_API_KEY&per_page=20' \
--header 'Content-Type: application/json'
Receita para Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"title": "climate",
"facet": true,
"facet.field": "source.country.id,language.id",
"facet.range": true,
"facet.range.field": "published_at",
"facet.range.start": "2024-01-01",
"facet.range.end": "2024-06-01",
"facet.range.gap": "1MONTH",
"api_key": "YOUR_API_KEY",
"per_page": 20
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Receita para Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"title": "climate",
"facet": true,
"facet.field": "source.country.id,language.id",
"facet.range": true,
"facet.range.field": "published_at",
"facet.range.start": "2024-01-01",
"facet.range.end": "2024-06-01",
"facet.range.gap": "1MONTH",
"api_key": "YOUR_API_KEY",
"per_page": 20
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Receita para PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'title' => 'climate',
'facet' => 1,
'facet.field' => 'source.country.id,language.id',
'facet.range' => 1,
'facet.range.field' => 'published_at',
'facet.range.start' => '2024-01-01',
'facet.range.end' => '2024-06-01',
'facet.range.gap' => '1MONTH',
'api_key' => 'YOUR_API_KEY',
'per_page' => 20,
],
]);
echo $response->getBody();
Receita para Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?title=climate&facet=1&facet.field=source.country.id%2Clanguage.id&facet.range=1&facet.range.field=published_at&facet.range.start=2024-01-01&facet.range.end=2024-06-01&facet.range.gap=1MONTH&api_key=YOUR_API_KEY&per_page=20")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();